@@ -8,7 +8,6 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions._utils import builtin_ops
 from jx_base.expressions.expression import Expression
@@ -16,15 +15,15 @@ from jx_base.expressions.false_op import FALSE
 from jx_base.expressions.literal import Literal
 from jx_base.expressions.null_op import NULL
 from jx_base.language import is_op
-from mo_json.types import T_NUMBER
+from mo_json.types import JX_NUMBER
 
 
 class BasicMultiOp(Expression):
     """
-    PLACEHOLDER FOR BASIC OPERATOR (CAN NOT DEAL WITH NULLS)
+    PLACEHOLDER FOR STRICT MULTI-VALUED OPERATIONS (CAN NOT DEAL WITH NULLS)
     """
 
-    _data_type = T_NUMBER
+    _jx_type = JX_NUMBER
     op = None
 
     def __init__(self, *terms):
@@ -69,4 +68,4 @@ class BasicMultiOp(Expression):
             if acc is not None:
                 terms.append(Literal(acc))
 
-            return self.__class__(terms)
+            return self.__class__(*terms)
