@@ -7,8 +7,7 @@
 #
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
-
-from __future__ import absolute_import, division, unicode_literals
+from mo_dots import is_missing
 
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.literal import Literal
@@ -16,16 +15,22 @@ from jx_base.expressions.literal import is_literal
 from jx_base.expressions.null_op import NULL
 from jx_base.language import is_op
 from mo_future import is_text
-from mo_json import T_INTEGER
+from mo_json import JX_INTEGER
 
 
 class LengthOp(Expression):
-    _data_type = T_INTEGER
+    _jx_type = JX_INTEGER
 
     def __init__(self, term):
         Expression.__init__(self, term)
         self.term = term
 
+    def __call__(self, row, rownum=None, rows=None):
+        value = self.term(row, rownum, rows)
+        if is_missing(value):
+            return None
+        return len(value)
+
     def __eq__(self, other):
         if is_op(other, LengthOp):
             return self.term == other.term
@@ -46,8 +51,8 @@ class LengthOp(Expression):
         term = self.term.partial_eval(lang)
         if is_literal(term):
             if is_text(term.value):
-                return Literal(len(term.value))
+                return lang.Literal(len(term.value))
             else:
                 return NULL
         else:
-            return LengthOp(term)
+            return lang.LengthOp(term)
