@@ -8,9 +8,9 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions.basic_substring_op import BasicSubstringOp
+from jx_base.expressions.coalesce_op import CoalesceOp
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.length_op import LengthOp
 from jx_base.expressions.literal import ZERO
@@ -18,26 +18,21 @@ from jx_base.expressions.literal import is_literal
 from jx_base.expressions.max_op import MaxOp
 from jx_base.expressions.min_op import MinOp
 from jx_base.expressions.or_op import OrOp
-from jx_base.expressions.variable import Variable
+from jx_base.expressions.variable import is_variable
 from jx_base.expressions.when_op import WhenOp
-from jx_base.language import is_op
-from mo_dots import is_data
-from mo_json.types import T_TEXT
+from mo_json.types import JX_TEXT
 
 
 class NotLeftOp(Expression):
     has_simple_form = True
-    _data_type = T_TEXT
+    _jx_type = JX_TEXT
 
-    def __init__(self, *term):
-        Expression.__init__(self, *term)
-        if is_data(term):
-            self.value, self.length = term.items()[0]
-        else:
-            self.value, self.length = term
+    def __init__(self, value, length):
+        Expression.__init__(self, value, length)
+        self.value, self.length = value, length
 
     def __data__(self):
-        if is_op(self.value, Variable) and is_literal(self.length):
+        if is_variable(self.value) and is_literal(self.length):
             return {"not_left": {self.value.var: self.length.value}}
         else:
             return {"not_left": [self.value.__data__(), self.length.__data__()]}
@@ -52,19 +47,15 @@ class NotLeftOp(Expression):
         return OrOp(self.value.missing(lang), self.length.missing(lang))
 
     def partial_eval(self, lang):
-        value = (self.value).partial_eval(lang)
+        value = self.value.partial_eval(lang)
         length = self.length.partial_eval(lang)
 
         if length is ZERO:
             return value
 
-        max_length = LengthOp(value)
+        max_length = CoalesceOp(LengthOp(value), ZERO)
         output = WhenOp(
             self.missing(lang),
-            **{"else": BasicSubstringOp(
-                value,
-                MaxOp(ZERO, MinOp(length, max_length)),
-                max_length,
-            )}
+            **{"else": BasicSubstringOp(value, MaxOp(ZERO, MinOp(length, max_length)), max_length)}
         ).partial_eval(lang)
         return output
