@@ -8,7 +8,6 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions.false_op import FALSE
 from jx_base.expressions.literal import Literal
@@ -16,7 +15,7 @@ from jx_base.expressions.true_op import TRUE
 from jx_base.language import TYPE_ORDER
 from mo_dots import Null
 from mo_imports import export
-from mo_json.types import T_IS_NULL
+from mo_json.types import JX_IS_NULL
 from mo_logs import Log
 
 
@@ -26,7 +25,7 @@ class NullOp(Literal):
     USE IT TO EXPECT A NULL VALUE IN assertAlmostEqual
     """
 
-    _data_type = T_IS_NULL
+    _jx_type = JX_IS_NULL
 
     @classmethod
     def define(cls, expr):
@@ -79,17 +78,14 @@ class NullOp(Literal):
         return FALSE
 
     @property
-    def type(self):
-        return T_IS_NULL
+    def jx_type(self):
+        return JX_IS_NULL
 
     def __call__(self, row=None, rownum=None, rows=None):
         return Null
 
-    def __unicode__(self):
-        return "null"
-
     def __str__(self):
-        return b"null"
+        return "null"
 
     def __hash__(self):
         return id(None)
