@@ -8,10 +8,8 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions.expression import Expression
-from mo_future import text
 from mo_logs import Log
 from mo_math import is_integer
 
@@ -45,8 +43,5 @@ class OffsetOp(Expression):
     def __eq__(self, other):
         return self.var == other
 
-    def __unicode__(self):
-        return text(self.var)
-
     def __str__(self):
         return str(self.var)
