@@ -8,19 +8,30 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.false_op import FALSE
-from mo_json import T_INTEGER
+from mo_json import JX_INTEGER
 
 
 class SqlInstrOp(Expression):
-    _data_type = T_INTEGER
+    """
+    CONSERVATIVE indexOf OPERATION (null PARAMETERS RETURN null)
+    RETURN POSITION OF find IN value
+    RETURN INDEX OF find IN value (FIRST CHARACTER IS 1)
+    RETURN 0 IF NOT FOUND
+    """
 
-    def __init__(self, *params):
-        Expression.__init__(self, params)
-        self.value, self.find = params
+    _jx_type = JX_INTEGER
+
+    def __init__(self, value, find):
+        Expression.__init__(self, value, find)
+        self.value, self.find = value, find
+
+    def __eq__(self, other):
+        if not isinstance(other, SqlInstrOp):
+            return False
+        return self.value == other.value and self.find == other.find
 
     def __data__(self):
         return {"sql.instr": [self.value.__data__(), self.find.__data__()]}
