@@ -16,7 +16,7 @@ from mo_json.types import JX_BOOLEAN
 
 
 class SqlIsNullOp(Expression):
-    _data_type = JX_BOOLEAN
+    _jx_type = JX_BOOLEAN
 
     def __init__(self, term):
         Expression.__init__(self, term)
