@@ -8,16 +8,15 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-
+from jx_base.expressions import NULL, FALSE
 from jx_base.expressions.expression import Expression
-from jx_base.expressions.false_op import FALSE
 from mo_json import JX_INTEGER
 
 
 class SqlSubstrOp(Expression):
     _jx_type = JX_INTEGER
 
-    def __init__(self, value, start, length):
+    def __init__(self, value, start, length=NULL):
         Expression.__init__(self, value, start, length)
         self.value, self.start, self.length = value, start, length
 
