@@ -8,18 +8,17 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
-
+from jx_base.expressions.expression import Expression, TRUE
 from mo_imports import export
-from jx_base.expressions.expression import Expression
-from jx_base.expressions.false_op import FALSE
-from jx_base.expressions.null_op import NULL
-from jx_base.expressions.not_op import NotOp
-from mo_json.types import T_BOOLEAN, T_INTEGER
+from mo_json import JX_BOOLEAN
 
 
 class ToBooleanOp(Expression):
-    _data_type = T_BOOLEAN
+    """
+    CONVERT VALUE TO BOOLEAN, OR KEEP AS BOOLEAN
+    """
+
+    _jx_type = JX_BOOLEAN
 
     def __init__(self, term):
         Expression.__init__(self, term)
@@ -28,6 +27,9 @@ class ToBooleanOp(Expression):
     def __data__(self):
         return {"boolean": self.term.__data__()}
 
+    def __eq__(self, other):
+        return isinstance(other, ToBooleanOp) and self.term == other.term
+
     def vars(self):
         return self.term.vars()
 
@@ -39,15 +41,11 @@ class ToBooleanOp(Expression):
 
     def partial_eval(self, lang):
         term = self.term.partial_eval(lang)
-        if term is NULL:
-            return FALSE
-        elif term.type is T_BOOLEAN:
+        if term.jx_type == JX_BOOLEAN or term.missing(lang) is TRUE:
             return term
         elif term is self.term:
             return self
-
-        exists = NotOp(term.missing(lang)).partial_eval(lang)
-        return exists
+        return ToBooleanOp(term)
 
 
 export("jx_base.expressions.and_op", ToBooleanOp)
