@@ -7,10 +7,9 @@
 #
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
-from __future__ import absolute_import, division, unicode_literals
 
 
-class Table:
+class Table():
     """
     POINT TO A SPECIFIC TABLE IN A CONTAINER
     """
