@@ -7,11 +7,11 @@
 #
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
-from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions import ModOp as ModOp_
+
+from jx_base.expressions import ModOp as _ModOp
 from jx_python.expressions._utils import _binaryop_to_python
 
 
-class ModOp(ModOp_):
+class ModOp(_ModOp):
     to_python = _binaryop_to_python
