@@ -28,13 +28,7 @@ class PythonFunction(_PythonFunction):
         self._name = f"boxed_function{randoms.string(8)}"
 
     def to_python(self, loop_depth=0):
-        return PythonScript(
-            {self._name: self.func},
-            loop_depth,
-            self.jx_type,
-            f"{self._name}(row{loop_depth})",
-            self,
-        )
+        return PythonScript({self._name: self.func}, loop_depth, self.jx_type, f"{self._name}(row{loop_depth})", self,)
 
     def __data__(self):
         return {"python_function": {}}
