@@ -26,7 +26,7 @@ class TallyOp(_TallyOp):
             loop_depth,
             JX_INTEGER,
             f"tally({','.join(t.source for t in terms)})",
-            self
+            self,
         )
 
 
@@ -36,4 +36,4 @@ def tally(*terms):
         if is_missing(t):
             return None
         output += 1
-    return output
\ No newline at end of file
+    return output
