@@ -19,10 +19,5 @@ class ToTextOp(_ToTextOp):
         missing = self.term.missing(Python).to_python(loop_depth)
         value = self.term.to_python(loop_depth)
         return PythonScript(
-            locals=value.locals,
-            loop_depth=loop_depth,
-            type=JX_TEXT,
-            source=value.source,
-            frum=self,
-            miss=missing
+            locals=value.locals, loop_depth=loop_depth, type=JX_TEXT, source=value.source, frum=self, miss=missing
         )
