@@ -18,11 +18,7 @@ class ToValueOp(_ToValueOp):
     def to_python(self, loop_depth=0):
         term = self.term.partial_eval(Python).to_python(loop_depth)
         return PythonScript(
-            merge_locals(term.locals, delist=delist),
-            loop_depth,
-            term.jx_type,
-            f"delist({term.source})",
-            self,
+            merge_locals(term.locals, delist=delist), loop_depth, term.jx_type, f"delist({term.source})", self,
         )
 
     def partial_eval(self, lang):
